/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodA/src/ExampleGetLocationMLP.java,v 1.2 2002/12/02 20:53:39 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

import com.signalsoftcorp.lst.client.SubscriberId;
import com.signalsoftcorp.lst.client.WLILocation;
import com.signalsoftcorp.lst.client.MLP300LocationRequest;
import com.signalsoftcorp.lst.client.MLP300LocationResponse;
import com.signalsoftcorp.lst.client.MLP300Msid;
import com.signalsoftcorp.lst.client.MLP300Position;

public class ExampleGetLocationMLP
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the LSt getLocation request with LIF MLP parameters.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleGetLocationMLP> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleGetLocationMLP> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        WLILocation lif = (WLILocation)Registry.bind( variables.getProperty("LStURL"), WLILocation.class );

        // build the request arguments
        MLP300Msid[] subscriberArray = { 
           new MLP300Msid(variables.getProperty("subscriber0Type"), variables.getProperty("subscriber0Id")),
           new MLP300Msid(variables.getProperty("subscriber1Type"), variables.getProperty("subscriber1Id")) };
        Integer respTimer = new Integer( variables.getProperty("respTimer") );
        Integer llAcc = new Integer( variables.getProperty("llAcc") );
        Integer horAcc = new Integer( variables.getProperty("horAcc") );
        Integer altAcc = new Integer( variables.getProperty("altAcc") );
        Integer maxLocAge = new Integer( variables.getProperty("maxLocAge") );

        // example of MLP300LocationRequest constructor
        MLP300LocationRequest request = new MLP300LocationRequest();
           request.setClientId( variables.getProperty("clientId") );
           request.setClientPwd( variables.getProperty("password") );
           request.setRespReq( variables.getProperty("respReq") );
           request.setRespTimer( respTimer.intValue() );
           request.setLlAcc( llAcc.intValue() );
           request.setHorAcc( horAcc.intValue() );
           request.setAltAcc( altAcc.intValue() );
           request.setMaxLocAge( maxLocAge.intValue() );
           request.setLocType( variables.getProperty("locType") );
           request.setPrioType( variables.getProperty("prioType") );
           request.setMLP300Msid(subscriberArray);

        // exmaples of MLP300LocationRequest get methods
        if ( request == null )
           System.out.println("ExampleGetLocationMLP> request is null");
        else
        {
           System.out.println("ExampleGetLocationMLP> request is:");
           System.out.println("              clientId = " + request.getClientId());
           System.out.println("              clientPwd = " + request.getClientPwd());
           System.out.println("              respReq = " + request.getRespReq());
           System.out.println("              respTimer = " + request.getRespTimer());
           System.out.println("              llAcc = " + request.getLlAcc());
           System.out.println("              horAcc = " + request.getHorAcc());
           System.out.println("              altAcc = " + request.getAltAcc());
           System.out.println("              maxLocAge = " + request.getMaxLocAge());
           System.out.println("              locType = " + request.getLocType());
           System.out.println("              prioType = " + request.getPrioType());
           MLP300Msid[] msidList = request.getMLP300Msid();
           if ( msidList == null )
              System.out.println("              response.getMLP300Msid() returned null");
           else if ( msidList.length < 1 )
              System.out.println("              msidList.length = " + msidList.length);
           else
           {
              for ( int i=0; i<msidList.length; i++ )
              {
                 System.out.println("              Msid[" + i + "] = " + msidList[i].toString());
              }
           }
        }

        // make the request by executing the getLocation() method with an MLP300LocationRequest argument
        System.out.println("ExampleGetLocationMLP> attempting getLocation");
        MLP300LocationResponse response = lif.getLocation( request );

        // If successful, the MLP300LocationResponse will contain an overall resId integer of 0 and an
        // overall result string of "OK".
        // But the reverse is NOT true, ie if the request failed for one or more of the Msids,
        // the overall resId integer may still be 0.  This is due to the fact that the LIF MLP spec does
        // NOT include any type of summary error code that can be used to indicate this condition.
        // Therefore, you MUST iterate through the MLP300Position array and look at the value of the
        // resId for each and every input Msid to determine if the request was totally successful or not.
        // Each element of the MLP300Position array will contain resId, result string, addInfo string
        //    and location information for each subscriber in the request.mLP300Msid array.
        // Note that some subscribers might be successfully located and some not.
        System.out.println("ExampleGetLocationMLP> response.getResId() = " + response.getResId());
        System.out.println("ExampleGetLocationMLP> response.getResult() = " + response.getResult());
        System.out.println("ExampleGetLocationMLP> response.getAddInfo() = " + response.getAddInfo());
        MLP300Position[] positions = response.getMLP300Positions();
        if ( positions == null )
           System.out.println("ExampleGetLocationMLP> response.getMLP300Positions() returned null");
        else if ( positions.length < 1 )
           System.out.println("ExampleGetLocationMLP> positions.length = " + positions.length);
        else
        {
           for ( int i=0; i<positions.length; i++ )
           {
              System.out.println("ExampleGetLocationMLP> response.MLP300Position[" + i + "]:");
              System.out.println("   time = " + positions[i].getTime());
              System.out.println("   x = " + positions[i].getX());
              System.out.println("   y = " + positions[i].getY());
              System.out.println("   z = " + positions[i].getZ());
              System.out.println("   radius = " + positions[i].getRadius());
              System.out.println("   altAcc = " + positions[i].getAltAcc());
              System.out.println("   alt = " + positions[i].getAlt());
              System.out.println("   speed = " + positions[i].getSpeed());
              System.out.println("   direction = " + positions[i].getDirection());
              System.out.println("   result = " + positions[i].getResult());
              System.out.println("   resId = " + positions[i].getResId());
              System.out.println("   utcOff = " + positions[i].getUtcOff());
              System.out.println("   levConf = " + positions[i].getLevConf());
              System.out.println("   addInfo = " + positions[i].getAddInfo());
              if ( positions[i].getMLP300Msid() == null )
                 System.out.println("   mLP300Msid = null");
              else {
                 System.out.println("   mLP300Msid.id = " + positions[i].getMLP300Msid().getId());
                 System.out.println("   mLP300Msid.type = " + positions[i].getMLP300Msid().getType());
              }
           }
        }
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleGetLocationMLP> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleGetLocationMLP> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
