/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodA/src/ExampleGetLocationSimple.java,v 1.2 2002/12/02 20:53:39 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

import com.signalsoftcorp.lst.client.SubscriberId;
import com.signalsoftcorp.lst.client.WLILocation;
import com.signalsoftcorp.lst.client.WLP10LocationRequest;
import com.signalsoftcorp.lst.client.WLP10LocationResponse;
import com.signalsoftcorp.lst.client.WLP10Position;

public class ExampleGetLocationSimple
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the LSt getLocation request with "simple" parameter set.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleGetLocationSimple> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleGetLocationSimple> attempting to bind to LStURL= " + 
                            variables.getProperty("LStURL"));
        WLILocation lif = (WLILocation)Registry.bind( variables.getProperty("LStURL"), WLILocation.class );

        // build the request arguments
        SubscriberId[] subscriberArray = { 
           new SubscriberId(variables.getProperty("subscriber0Type"), variables.getProperty("subscriber0Id")),
           new SubscriberId(variables.getProperty("subscriber1Type"), variables.getProperty("subscriber1Id")) };
        Integer timeOut = new Integer( variables.getProperty("timeOut") );
        Integer maxLocAge = new Integer( variables.getProperty("maxLocAge") );

        // example of WLP10LocationRequest constructor
        WLP10LocationRequest request = new WLP10LocationRequest(
           subscriberArray,
           timeOut.intValue(),
           maxLocAge.intValue());

        // examples of WLP10LocationRequest get methods
        if ( request == null )
           System.out.println("ExampleGetLocationSimple> request is null");
        else
        {
           System.out.println("ExampleGetLocationSimple> request is:");
           System.out.println("              timeOut = " + request.getTimeout());
           System.out.println("              maxLocAge = " + request.getMaxLocAge());
           SubscriberId[] subscriberList = request.getSubscribers();
           if ( subscriberList == null )
              System.out.println("              request.getSubscribers() returned null");
           else if ( subscriberList.length < 1 )
              System.out.println("              subscriberList.length = " + subscriberList.length);
           else
           {
              for ( int i=0; i<subscriberList.length; i++ )
              {
                 System.out.println("              subscriber[" + i + "] = " + subscriberList[i].toString());
              }
           }
        }

        // make the request by executing the getLocation() method with an WLP10LocationRequest argument
        System.out.println("ExampleGetLocationSimple> attempting getLocation");
        WLP10LocationResponse response = lif.getLocation(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the WLP10LocationResponse will contain an overall responseCode integer of 0 and
        // a responseDetail string of "OK".
        // But the reverse is NOT true, ie if the request failed for one or more of the subscribers,
        // the overall responseCode integer may still be 0.  This is due to the fact that the LIF MLP spec does
        // NOT include any type of summary error code that can be used to indicate this condition (and
        // this simplified location request is a simplification of the LIF MLP specification).
        // Therefore, you MUST iterate through the WLP10Position array and look at the value of the
        // responseCode integer for each and every input subscriber to determine if the request was
        // totally successful or not.
        // Each element of the wLI10Position array contains a responseCode integer, responseDetail string
        // and  location information for each subscriber in the request.subscribers array.
        // Note that some subscribers can be successfully located and some not.
        System.out.println("ExampleGetLocationSimple> response.getResponseCode() = " + response.getResponseCode());
        System.out.println("ExampleGetLocationSimple> response.getResponseDetail() = " + response.getResponseDetail());
        WLP10Position[] positions = response.getWLP10Position();
        if ( positions == null )
           System.out.println("ExampleGetLocationSimple> response.getWLP10Position() returned null");
        else if ( positions.length < 1 )
           System.out.println("ExampleGetLocationSimple> positions.length = " + positions.length);
        else
        {
           for ( int i=0; i<positions.length; i++ )
           {
              System.out.println("ExampleGetLocationSimple> response.positions[" + i + "]:");
              System.out.println("   responseCode = " + positions[i].getResponseCode());
              System.out.println("   responseDetail = " + positions[i].getResponseDetail());
              System.out.println("   time = " + positions[i].getTime());
              System.out.println("   latitude = " + positions[i].getLatitude());
              System.out.println("   longitude = " + positions[i].getLongitude());
              System.out.println("   radius = " + positions[i].getRadius());
              if ( positions[i].getSubscriberId() == null )
                 System.out.println("   subscriber = null");
              else {
                 System.out.println("   subscriber.id = " + positions[i].getSubscriberId().getId());
                 System.out.println("   subscriber.type = " + positions[i].getSubscriberId().getType());
              }
           }
        }
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleGetLocationSimple> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleGetLocationSimple> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
