/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodA/src/ExampleInitiateVerifySubscriber.java,v 1.2 2002/12/02 20:53:39 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

import com.signalsoftcorp.lst.client.SubscriberId;
import com.signalsoftcorp.lst.client.WVIValidation;
import com.signalsoftcorp.lst.client.WVP10InitRequest;
import com.signalsoftcorp.lst.client.WVP10InitResponse;

public class ExampleInitiateVerifySubscriber
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the initiateVerifySubscriber method
     // of the LSt Validation web service.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleInitiateVerifySubscriber> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleInitiateVerifySubscriber> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        WVIValidation vif = (WVIValidation)Registry.bind( variables.getProperty("LStURL"), WVIValidation.class );

        // build the request arguments
        SubscriberId subscriber = new SubscriberId( variables.getProperty("subscriber0Type"),
                                                    variables.getProperty("subscriber0Id") );
        Boolean validateSub = new Boolean( variables.getProperty("validateSub") );

        // example of WVP10InitRequest constructor
        WVP10InitRequest request = new WVP10InitRequest(
           subscriber,
           variables.getProperty("message"),
           variables.getProperty("codeSignature"),
           variables.getProperty("messageDelimiter"),
           validateSub.booleanValue() );

        // examples of WVP10InitRequest get methods
        if ( request == null )
           System.out.println("ExampleInitiateVerifySubscriber> request is null");
        else
        {
           System.out.println("ExampleInitiateVerifySubscriber> request is:");
           System.out.println("              subscriber = " + request.getSubscriber().toString());
           System.out.println("              message = " + request.getMessage());
           System.out.println("              codeSignature = " + request.getCodeSignature());
           System.out.println("              messageDelimiter = " + request.getMessageDelimiter());
           System.out.println("              validateSub = " + request.getValidateSubscription());
        }

        // make the request by executing the initiateVerifySubscriber() method
        System.out.println("ExampleInitiateVerifySubscriber> attempting initiateVerifySubscriber");
        WVP10InitResponse response = vif.initiateVerifySubscriber(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the response code integer should be 0
        // and the response detail string should be "OK".
        System.out.println("ExampleInitiateVerifySubscriber> getResponseCode() = " + response.getResponseCode());
        System.out.println("ExampleInitiateVerifySubscriber> getResponseDetail() = " + response.getResponseDetail());
        System.out.println("ExampleInitiateVerifySubscriber> getVerificationAlias() = " + 
                                                         response.getVerificationAlias());
        if ( response.getTransferredDate() == null )
           System.out.println("ExampleInitiateVerifySubscriber> getTransferredDate() returned null");
        else
           System.out.println("ExampleInitiateVerifySubscriber> getTransferredDate() = " + 
                                                     response.getTransferredDate().toString());
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleInitiateVerifySubscriber> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleInitiateVerifySubscriber> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
