/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodA/src/ExampleSendWapMessage.java,v 1.2 2002/12/02 20:53:39 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

import com.signalsoftcorp.lst.client.SubscriberId;
import com.signalsoftcorp.lst.client.WMIMessaging;
import com.signalsoftcorp.lst.client.WMP10WapRequest;
import com.signalsoftcorp.lst.client.WMP10MessagingResponse;
import com.signalsoftcorp.lst.client.WMP10SubscriberStatus;

public class ExampleSendWapMessage
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the LSt sendWapMessage web service.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleSendWapMessage> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleSendWapMessage> attempting to bind to LStURL= " +
                            variables.getProperty("LStURL"));
        WMIMessaging mif = (WMIMessaging)Registry.bind( variables.getProperty("LStURL"), WMIMessaging.class );

        // build the request argument
        SubscriberId[] subscriberArray = { 
           new SubscriberId(variables.getProperty("subscriber0Type"), variables.getProperty("subscriber0Id")),
           new SubscriberId(variables.getProperty("subscriber1Type"), variables.getProperty("subscriber1Id")) };

        // example of WMP10WapRequest constructor
        WMP10WapRequest request = new WMP10WapRequest(
           variables.getProperty("wapBody"),
           variables.getProperty("wapMediaType"),
           subscriberArray);

        // examples of WMP10WapRequest get methods
        if ( request == null )
           System.out.println("ExampleSendWapMessage> request is null");
        else
        {
           System.out.println("ExampleSendWapMessage> request is:");
           System.out.println("              body = " + request.getBody());
           System.out.println("              mediaType = " + request.getMediaType());
           SubscriberId[] recipientList = request.getRecipients();
           if ( recipientList == null )
              System.out.println("              recipient list is null");
           else
           {
              for ( int i=0; i<recipientList.length; i++ )
              {
                 System.out.println("              subscriber[" + i + "] = " + recipientList[i].toString());
              }
           }
        }


        // make the request by executing the sendWapMessage() method
        System.out.println("ExampleSendWapMessage> attempting sendWapMessage");
        WMP10MessagingResponse response = mif.sendWapMessage( 
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the WMP10MessagingResponse will contain a responseCode integer of 0 and
        // a responseDetail string of "OK".  Each element of the subscriberStatus array will contain
        // responseCode integer and responseDetail string and a SubscriberId element for each of the
        // subscribers in the request.
        // Note that the request may be successful for some subscribers and unsuccessful for others.
        System.out.println("ExampleSendWapMessage> response.getResponseCode() = " + response.getResponseCode());
        System.out.println("ExampleSendWapMessage> response.getResponseDetail() = " + response.getResponseDetail());
        WMP10SubscriberStatus[] statusArray = response.getSubscriberStatus();
        if ( statusArray == null )
           System.out.println("ExampleSendWapMessage> response.getSubscriberStatus() returned null");
        else if ( statusArray.length < 1 )
           System.out.println("ExampleSendWapMessage> statusArray.length = " + statusArray.length);
        else
        {
           for ( int i=0; i<statusArray.length; i++ )
           {
              System.out.println("ExampleSendWapMessage> Response.subscriberStatus[" + i + "]:");
              System.out.println("      responseCode = " + statusArray[i].getResponseCode());
              System.out.println("      responseDetail = " + statusArray[i].getResponseDetail());
              System.out.println("      subscriber.id = " + statusArray[i].getSubscriberId().getId());
              System.out.println("      subscriber.type = " + statusArray[i].getSubscriberId().getType());
           }
        }

     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleSendWapMessage> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleSendWapMessage> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
