/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodB/src/ExampleCompleteVerifySubscriber.java,v 1.2 2002/12/02 20:58:23 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

public class ExampleCompleteVerifySubscriber
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the completeVerifySubscriber method
     // of the LSt Validation web service.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleCompleteVerifySubscriber> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleCompleteVerifySubscriber> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        IWVIValidation vif = (IWVIValidation)Registry.bind( variables.getProperty("LStURL"), IWVIValidation.class );

        // example of WVP10CompletionRequest constructor
        WVP10CompletionRequest request = new WVP10CompletionRequest();
           request.verificationAlias = variables.getProperty("verificationAlias");
           request.code = variables.getProperty("code");

        // make the request by executing the completeVerifySubscriber() method
        System.out.println("ExampleCompleteVerifySubscriber> attempting completeVerifySubscriber");
        WVP10CompletionResponse response = vif.completeVerifySubscriber(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the response code integer should be 0
        // and the response detail string should be "OK".
        System.out.println("ExampleCompleteVerifySubscriber> response.responseCode = " + response.responseCode);
        System.out.println("ExampleCompleteVerifySubscriber> response.responseDetail = " + response.responseDetail);
        if ( response.subscriber == null )
           System.out.println("ExampleCompleteVerifySubscriber> response.subscriber is null");
        else
           System.out.println("ExampleCompleteVerifySubscriber> response.subscriber = " + 
                                                         response.subscriber.toString());
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleCompleteVerifySubscriber> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleCompleteVerifySubscriber> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
