/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodB/src/ExampleGetLocationMLP.java,v 1.2 2002/12/02 20:58:23 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

public class ExampleGetLocationMLP
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the LSt getLocation request with LIF MLP parameters.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleGetLocationMLP> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleGetLocationMLP> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        IWLILocation lif = (IWLILocation)Registry.bind( variables.getProperty("LStURL"), IWLILocation.class );

        // build the request arguments
        MLP300Msid[] subscriberArray = { new MLP300Msid(), new MLP300Msid() };
           subscriberArray[0].type = variables.getProperty("subscriber0Type");
           subscriberArray[0].id = variables.getProperty("subscriber0Id");
           subscriberArray[1].type = variables.getProperty("subscriber1Type");
           subscriberArray[1].id = variables.getProperty("subscriber1Id");
        Integer respTimer = new Integer( variables.getProperty("respTimer") );
        Integer llAcc = new Integer( variables.getProperty("llAcc") );
        Integer horAcc = new Integer( variables.getProperty("horAcc") );
        Integer altAcc = new Integer( variables.getProperty("altAcc") );
        Integer maxLocAge = new Integer( variables.getProperty("maxLocAge") );

        MLP300LocationRequest request = new MLP300LocationRequest();
           request.clientId =   variables.getProperty("clientId");
           request.clientPwd =  variables.getProperty("password");
           request.respReq =    variables.getProperty("respReq");
           request.respTimer =  respTimer.intValue();
           request.llAcc =      llAcc.intValue();
           request.horAcc =     horAcc.intValue();
           request.altAcc =     altAcc.intValue();
           request.maxLocAge =  maxLocAge.intValue();
           request.locType =    variables.getProperty("locType");
           request.prioType =   variables.getProperty("prioType");
           request.mLP300Msid = subscriberArray;

        // make the request by executing the getLocation() method
        System.out.println("ExampleGetLocationMLP> attempting getLocation");
        MLP300LocationResponse response = lif.getLocation( request );

        // If successful, the MLP300LocationResponse will contain an overall resId integer of 0 and an
        // overall result string of "OK".
        // But the reverse is NOT true, ie if the request failed for one or more of the Msids,
        // the overall resId integer may still be 0.  This is due to the fact that the LIF MLP spec does
        // NOT include any type of summary error code that can be used to indicate this condition.
        // Therefore, you MUST iterate through the MLP300Position array and look at the value of the
        // resId for each and every input Msid to determine if the request was totally successful or not.
        // Each element of the MLP300Position array will contain resId, result string, addInfo string
        //    and location information for each subscriber in the request.mLP300Msid array.
        // Note that some subscribers might be successfully located and some not.
        System.out.println("ExampleGetLocationMLP> response.resId = " + response.resId);
        System.out.println("ExampleGetLocationMLP> response.result = " + response.result);
        System.out.println("ExampleGetLocationMLP> response.addInfo = " + response.addInfo);
        if ( response.mLP300Positions == null )
           System.out.println("ExampleGetLocationMLP> response.mLP300Positions is null");
        else if ( response.mLP300Positions.length < 1 )
           System.out.println("ExampleGetLocationMLP> response.mLP300Positions.length = " +
                                                  response.mLP300Positions.length);
        else
        {
           for ( int i=0; i<response.mLP300Positions.length; i++ )
           {
              System.out.println("ExampleGetLocationMLP> response.MLP300Position[" + i + "]:");
              System.out.println("   time = " + response.mLP300Positions[i].time);
              System.out.println("   x = " + response.mLP300Positions[i].x);
              System.out.println("   y = " + response.mLP300Positions[i].y);
              System.out.println("   z = " + response.mLP300Positions[i].z);
              System.out.println("   radius = " + response.mLP300Positions[i].radius);
              System.out.println("   altAcc = " + response.mLP300Positions[i].altAcc);
              System.out.println("   alt = " + response.mLP300Positions[i].alt);
              System.out.println("   speed = " + response.mLP300Positions[i].speed);
              System.out.println("   direction = " + response.mLP300Positions[i].direction);
              System.out.println("   result = " + response.mLP300Positions[i].result);
              System.out.println("   resId = " + response.mLP300Positions[i].resId);
              System.out.println("   utcOff = " + response.mLP300Positions[i].utcOff);
              System.out.println("   levConf = " + response.mLP300Positions[i].levConf);
              System.out.println("   addInfo = " + response.mLP300Positions[i].addInfo);
              System.out.println("   mLP300Msid.id = " + response.mLP300Positions[i].mLP300Msid.id);
              System.out.println("   mLP300Msid.type = " + response.mLP300Positions[i].mLP300Msid.type);
           }
        }
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleGetLocationMLP> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleGetLocationMLP> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
