/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodB/src/ExampleGetLocationSimple.java,v 1.2 2002/12/02 20:58:23 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

public class ExampleGetLocationSimple
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the LSt getLocation request with "simple" parameter set.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleGetLocationSimple> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleGetLocationSimple> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        IWLILocation lif = (IWLILocation)Registry.bind( variables.getProperty("LStURL"), IWLILocation.class );

        // build the request arguments
        SubscriberId[] subscriberArray = { new SubscriberId(), new SubscriberId() };
           subscriberArray[0].type = variables.getProperty("subscriber0Type");
           subscriberArray[0].id = variables.getProperty("subscriber0Id");
           subscriberArray[1].type = variables.getProperty("subscriber1Type");
           subscriberArray[1].id = variables.getProperty("subscriber1Id");
        Integer timeOut = new Integer( variables.getProperty("timeOut") );
        Integer maxLocAge = new Integer( variables.getProperty("maxLocAge") );

        WLP10LocationRequest request = new WLP10LocationRequest();
           request.timeout =     timeOut.intValue();
           request.maxLocAge =   maxLocAge.intValue();
           request.subscribers = subscriberArray;

        // make the request by executing the getLocation() method
        System.out.println("ExampleGetLocationSimple> attempting getLocation");
        WLP10LocationResponse response = lif.getLocation(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the WLP10LocationResponse will contain an overall responseCode integer of 0 and
        // a responseDetail string of "OK".
        // But the reverse is NOT true, ie if the request failed for one or more of the subscribers,
        // the overall responseCode integer may still be 0.  This is due to the fact that the LIF MLP spec does
        // NOT include any type of summary error code that can be used to indicate this condition (and
        // this simplified location request is a simplification of the LIF MLP specification).
        // Therefore, you MUST iterate through the WLP10Position array and look at the value of the
        // responseCode integer for each and every input subscriber to determine if the request was
        // totally successful or not.
        // Each element of the wLI10Position array contains a responseCode integer, responseDetail string
        // and  location information for each subscriber in the request.subscribers array.
        // Note that some subscribers can be successfully located and some not.
        System.out.println("ExampleGetLocationSimple> response.responseCode = " + response.responseCode);
        System.out.println("ExampleGetLocationSimple> response.responseDetail = " + response.responseDetail);
        if ( response.wLI10Position == null )
           System.out.println("ExampleGetLocationSimple> response.wLI10Position is null");
        else if ( response.wLI10Position.length < 1 )
           System.out.println("ExampleGetLocationSimple> response.wLI10Position.length = " +
                               response.wLI10Position.length);
        else
        {
           for ( int i=0; i<response.wLI10Position.length; i++ )
           {
              System.out.println("ExampleGetLocationSimple> response.wLI10Position[" + i + "]:");
              System.out.println("   responseCode = " + response.wLI10Position[i].responseCode);
              System.out.println("   responseDetail = " + response.wLI10Position[i].responseDetail);
              System.out.println("   time = " + response.wLI10Position[i].time);
              System.out.println("   latitude = " + response.wLI10Position[i].latitude);
              System.out.println("   longitude = " + response.wLI10Position[i].longitude);
              System.out.println("   radius = " + response.wLI10Position[i].radius);
              System.out.println("   subscriber.id = " + response.wLI10Position[i].subscriber.id);
              System.out.println("   subscriber.type = " + response.wLI10Position[i].subscriber.type);
           }
        }
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleGetLocationSimple> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleGetLocationSimple> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
