/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodB/src/ExampleInitiateVerifySubscriber.java,v 1.2 2002/12/02 20:58:23 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

public class ExampleInitiateVerifySubscriber
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the initiateVerifySubscriber method
     // of the LSt Validation web service.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleInitiateVerifySubscriber> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleInitiateVerifySubscriber> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        IWVIValidation vif = (IWVIValidation)Registry.bind( variables.getProperty("LStURL"), IWVIValidation.class );

        // build the request arguments
        SubscriberId subscriber = new SubscriberId();
           subscriber.type = variables.getProperty("subscriber0Type");
           subscriber.id = variables.getProperty("subscriber0Id");
        Boolean validateSub = new Boolean( variables.getProperty("validateSub") );

        // example of WVP10InitRequest constructor
        WVP10InitRequest request = new WVP10InitRequest();
           request.subscriber = subscriber;
           request.message = variables.getProperty("message");
           request.codeSignature = variables.getProperty("codeSignature");
           request.messageDelimiter = variables.getProperty("messageDelimiter");
           request.validateSubscription = validateSub.booleanValue();

        // make the request by executing the initiateVerifySubscriber() method
        System.out.println("ExampleInitiateVerifySubscriber> attempting initiateVerifySubscriber");
        WVP10InitResponse response = vif.initiateVerifySubscriber(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the response code integer should be 0
        // and the response detail string should be "OK".
        System.out.println("ExampleInitiateVerifySubscriber> response.responseCode = " + response.responseCode);
        System.out.println("ExampleInitiateVerifySubscriber> response.responseDetail = " + response.responseDetail);
        System.out.println("ExampleInitiateVerifySubscriber> response.verificationAlias = " + 
                                                         response.verificationAlias);
        if ( response.transferredDate == null )
           System.out.println("ExampleInitiateVerifySubscriber> response.transferredDate is null");
        else
           System.out.println("ExampleInitiateVerifySubscriber> response.transferredDate = " + 
                                                     response.transferredDate.toString());
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleInitiateVerifySubscriber> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleInitiateVerifySubscriber> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
