/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodB/src/ExampleSendEvent.java,v 1.2 2002/12/02 20:58:23 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Date;
import java.util.Properties;

public class ExampleSendEvent
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the LSt Event Billing web service.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleSendEvent> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleSendEvent> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        IWBIBilling bif = (IWBIBilling)Registry.bind( variables.getProperty("LStURL"), IWBIBilling.class );

        // build the request argument
        SubscriberId subscriber = new SubscriberId();
          subscriber.type = variables.getProperty("subscriber0Type");
          subscriber.id = variables.getProperty("subscriber0Id");
        Date startTime = new Date();
        Date endTime =  new Date(startTime.getTime() + 11000);

        WBP10BillingRequest request = new WBP10BillingRequest();
           request.eventId =    variables.getProperty("eventId");
           request.subscriber = subscriber;
           request.startTime =  startTime;
           request.endTime =    endTime;
           request.trackingId = variables.getProperty("trackingId");

        // make the request by executing the sendEvent() method
        System.out.println("ExampleSendEvent> attempting sendEvent");
        WBP10BillingResponse response = bif.sendEvent(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the response code integer should be 0
        // and the response detail string should be "OK".
        // If successful, LSt will write a billing event record into the billing log file.
        // For this example, the resulting billing event record looks like:
        // ATDR_20_WBI10|2|2002/10/14 13:46:48|LSt|OK|0:078|rosesclient|3037173126|MSID\
        // |3037173126|test eventId|2002/10/1 4 13:46:48:734|2002/10/14 13:46:48:734|test trackingID
        System.out.println("ExampleSendEvent: response.responseCode = " + response.responseCode);
        System.out.println("ExampleSendEvent: response.responseDetail = " + response.responseDetail);
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleSendEvent> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleSendEvent> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
