/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodB/src/ExampleSendWapMessage.java,v 1.2 2002/12/02 20:58:23 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

public class ExampleSendWapMessage
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the LSt sendWapMessage web service.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleSendWapMessage> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleSendWapMessage> attempting to bind to LStURL = " +
                           variables.getProperty("LStURL"));
        IWMIMessaging mif = (IWMIMessaging)Registry.bind( variables.getProperty("LStURL"), IWMIMessaging.class );

        // build the request argument
        SubscriberId[] subscriberArray = { new SubscriberId(), new SubscriberId() };
           subscriberArray[0].type = variables.getProperty("subscriber0Type");
           subscriberArray[0].id = variables.getProperty("subscriber0Id");
           subscriberArray[1].type = variables.getProperty("subscriber1Type");
           subscriberArray[1].id = variables.getProperty("subscriber1Id");

        WMP10WapRequest request = new WMP10WapRequest();
           request.mediaType =  variables.getProperty("wapMediaType");
           request.body =       variables.getProperty("wapBody");;
           request.recipients = subscriberArray;

        // make the request by executing the sendWapMessage() method
        System.out.println("ExampleSendWapMessage> attempting sendWapMessage");
        WMP10MessagingResponse response = mif.sendWapMessage(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           request );

        // If successful, the WMP10MessagingResponse will contain a responseCode integer of 0 and
        // a responseDetail string of "OK".  Each element of the subscriberStatus array will contain
        // responseCode integer and responseDetail string and a SubscriberId element for each of the
        // subscribers in the request.
        // Note that some subscribers can be successfully located and some not.
        System.out.println("ExampleSendWapMessage> response.responseCode = " + response.responseCode);
        System.out.println("ExampleSendWapMessage> response.responseDetail = " + response.responseDetail);
        if ( response.subscriberStatus == null )
             System.out.println("ExampleSendWapMessage> response.subscriberStatus[] is null");
        else if ( response.subscriberStatus.length < 1 )
             System.out.println("ExampleSendWapMessage> response.subscriberStatus.length = " +
                                 response.subscriberStatus.length);
        else
        {
           for ( int i=0; i<response.subscriberStatus.length; i++ )
           {
              System.out.println("ExampleSendWapMessage> response.subscriberStatus[" + i + "]:");
              System.out.println("   responseCode = " + response.subscriberStatus[i].responseCode);
              System.out.println("   responseDetail = " + response.subscriberStatus[i].responseDetail);
              System.out.println("   subscriber.id = " + response.subscriberStatus[i].subscriberId.id);
              System.out.println("   subscriber.type = " + response.subscriberStatus[i].subscriberId.type);
           }
        }

     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleSendWapMessage> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleSendWapMessage> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
