/**************************************************************************
 *
 *   Copyright (c) 2002 Openwave Systems Inc.  All rights reserved.
 *
 *   Openwave Systems Inc. grants you the right to use the Openwave Location
 *   Studio SDK software and its related documentation only according
 *   to Openwave's Location Studio SDK End User Software License Agreement.
 *
 *   Openwave and the Openwave logo are registered trademarks of Openwave
 *   Systems Inc. All other trademarks and registered trademarks are the
 *   properties of their respective owners.
 *
 **************************************************************************
 * $Header: /development/WLS/CVS/SDKLSt/MethodB/src/ExampleValidateSubscription.java,v 1.2 2002/12/02 20:58:23 rreynold Exp $
 **************************************************************************/

import electric.registry.Registry;
import electric.registry.RegistryException;

import java.io.FileInputStream;
import java.util.Properties;

public class ExampleValidateSubscription
{
   public static void main(String[] args) throws Exception
   {
     // This main is an example of how to use the validateSubscription method of the LSt Validation web service.

     try 
     {
        // Get the variables of this interface from the example_variables.properties file.
        // Use a command line argument to specify a different properties file.
        String property_filename = "example_variables.properties";
        if ( args.length > 0 ) property_filename = args[0];
        System.out.println("ExampleValidateSubscription> using property file " + property_filename);

        FileInputStream property_file = new FileInputStream( property_filename );
        Properties variables = new Properties();
        variables.load( property_file );

        // first use electric Registry to bind to the LSt web service
        System.out.println("ExampleValidateSubscription> attempting to bind to LStURL = " +
                            variables.getProperty("LStURL"));
        IWVIValidation vif = (IWVIValidation)Registry.bind( variables.getProperty("LStURL"), IWVIValidation.class );

        // build the request argument
        SubscriberId subscriber = new SubscriberId();
          subscriber.type = variables.getProperty("subscriber0Type");
          subscriber.id =   variables.getProperty("subscriber0Id");

        // make the request by executing the validateSubscription() method
        System.out.println("ExampleValidateSubscription> attempting validateSubscription");
        WVP10ValidationResponse response = vif.validateSubscription(
           variables.getProperty("clientId"),
           variables.getProperty("password"),
           subscriber);

        // If successful, the response code integer should be 0
        // and the response detail string should be "OK".
        System.out.println("ExampleValidateSubscription> response.responseCode = " + response.responseCode);
        System.out.println("ExampleValidateSubscription> response.responseDetail = " + response.responseDetail);
        System.out.println("ExampleValidateSubscription> response.operatorName = " + response.operatorName);
        if ( response.transferredDate == null )
           System.out.println("ExampleValidateSubscription> response.transferredDate is null");
        else
           System.out.println("ExampleValidateSubscription> response.transferredDate = " + 
                                                     response.transferredDate.toString());
     }
     catch ( RegistryException re )
     {
         System.out.println("ExampleValidateSubscription> RegistryException");
         System.out.println( re );
         System.out.println( "RegistryException.getCause() = " + re.getCause() );
         throw re;
     }
     catch ( Exception e )
     {
         System.out.println("ExampleValidateSubscription> Exception");
         System.out.println( e );
         throw e;
     }
   }
}
